@@ -239,7 +239,7 @@ __all__ = ["compile", "escape", "findall", "finditer", "fullmatch", "match",
   "U", "UNICODE", "V0", "VERSION0", "V1", "VERSION1", "X", "VERBOSE", "W",
   "WORD", "error", "Regex"]
 
-__version__ = "2.4.134"
+__version__ = "2.4.147"
 
 # --------------------------------------------------------------------
 # Public interface.
@@ -354,7 +354,9 @@ def template(pattern, flags=0):
     return _compile(pattern, flags | TEMPLATE)
 
 def escape(pattern, special_only=True, literal_spaces=False):
-    "Escape all non-alphanumeric characters or special characters in pattern."
+    """Escape a string for use as a literal in a pattern. If special_only is
+    True, escape only special characters, else escape all non-alphanumeric
+    characters. If literal_spaces is True, don't escape spaces."""
     s = []
     if special_only:
         for c in pattern:
@@ -461,7 +463,7 @@ def _compile(pattern, flags=0, kwargs={}):
         guess_encoding = UNICODE
     elif isinstance(pattern, str):
         guess_encoding = ASCII
-    elif isinstance(pattern, _pattern_type):
+    elif isinstance(pattern, Pattern):
         if flags:
             raise ValueError("cannot process flags argument with a compiled pattern")
 
@@ -672,8 +674,9 @@ def _compile_replacement_helper(pattern, template):
 
     return compiled
 
-# We define _pattern_type here after all the support objects have been defined.
-_pattern_type = type(_compile("", 0, {}))
+# We define Pattern here after all the support objects have been defined.
+Pattern = type(_compile('', 0, {}))
+Match = type(_compile('', 0).match(''))
 
 # We'll define an alias for the 'compile' function so that the repr of a
 # pattern object is eval-able.
@@ -685,7 +688,7 @@ import copy_reg as _copy_reg
 def _pickle(pattern):
     return _regex.compile, pattern._pickled_data
 
-_copy_reg.pickle(_pattern_type, _pickle)
+_copy_reg.pickle(Pattern, _pickle)
 
 if not hasattr(str, "format"):
     # Strings don't have the .format method (below Python 2.6).
